pub struct ChapterDownloadTask { /* private fields */ }Trait Implementations
Sourceimpl Actor for ChapterDownloadTask
impl Actor for ChapterDownloadTask
Sourcetype Context = Context<ChapterDownloadTask>
type Context = Context<ChapterDownloadTask>
Actor execution context type
Sourcefn stopping(&mut self, _ctx: &mut Self::Context) -> Running
fn stopping(&mut self, _ctx: &mut Self::Context) -> Running
Called after an actor is in
Actor::Stopping state. Read moreSourcefn started(&mut self, ctx: &mut Self::Context)
fn started(&mut self, ctx: &mut Self::Context)
Called when an actor gets polled the first time.
Sourcefn start_in_arbiter<F>(wrk: &ArbiterHandle, f: F) -> Addr<Self>
fn start_in_arbiter<F>(wrk: &ArbiterHandle, f: F) -> Addr<Self>
Start new actor in arbiter’s thread.
Sourceimpl CanBeWaited for ChapterDownloadTask
impl CanBeWaited for ChapterDownloadTask
Sourceimpl Cancelable for ChapterDownloadTask
impl Cancelable for ChapterDownloadTask
Sourceimpl Debug for ChapterDownloadTask
impl Debug for ChapterDownloadTask
Sourceimpl Drop for ChapterDownloadTask
impl Drop for ChapterDownloadTask
Sourceimpl Handler<DownloadMode> for ChapterDownloadTask
impl Handler<DownloadMode> for ChapterDownloadTask
Sourceimpl Handler<StartDownload> for ChapterDownloadTask
impl Handler<StartDownload> for ChapterDownloadTask
Sourceimpl Handler<SubcribeMessage<DownloadTaskState<ApiObject<ChapterAttributes>, ChapterDownloadingState>>> for ChapterDownloadTask
impl Handler<SubcribeMessage<DownloadTaskState<ApiObject<ChapterAttributes>, ChapterDownloadingState>>> for ChapterDownloadTask
Sourcetype Result = <SubcribeMessage<DownloadTaskState<ApiObject<ChapterAttributes>, ChapterDownloadingState>> as Message>::Result
type Result = <SubcribeMessage<DownloadTaskState<ApiObject<ChapterAttributes>, ChapterDownloadingState>> as Message>::Result
The type of value that this handler will return. Read more
Sourceimpl Handler<WaitForFinishedMessage<ApiObject<ChapterAttributes>, ChapterDownloadingState>> for ChapterDownloadTask
impl Handler<WaitForFinishedMessage<ApiObject<ChapterAttributes>, ChapterDownloadingState>> for ChapterDownloadTask
Sourcetype Result = <WaitForFinishedMessage<ApiObject<ChapterAttributes>, ChapterDownloadingState> as Message>::Result
type Result = <WaitForFinishedMessage<ApiObject<ChapterAttributes>, ChapterDownloadingState> as Message>::Result
The type of value that this handler will return. Read more
Sourceimpl State for ChapterDownloadTask
impl State for ChapterDownloadTask
type State = DownloadTaskState<ApiObject<ChapterAttributes>, ChapterDownloadingState>
fn inner_state(&self) -> Self::State
fn state(&self) -> TaskState
Sourceimpl Subscribe for ChapterDownloadTask
impl Subscribe for ChapterDownloadTask
fn subscribe( &mut self, subscriber: MaybeWeakRecipient<TaskSubscriberMessages<Self::State>>, )